==> apache-hop-2.0.0-src.tar.gz: apache-hop-2.0.0/plugins/transforms/concatfields/src/main/java/org/apache/hop/pipeline/transforms/concatfields/ConcatFieldsData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.concatfields;

import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;

/*
 * ConcatFieldsData
 *
 */
public class ConcatFieldsData extends BaseTransformData implements ITransformData {
  public int[] fieldnrs;
  public int posTargetField;
  public int[] remainingFieldsInputOutputMapping;
  public IRowMeta outputRowMeta;
  public IRowMeta inputRowMetaModified; // the field precisions and lengths are altered! see
  // TextFileOutputMeta.getFields().
  public String stringSeparator;
  public String stringEnclosure;
  public String[] stringNullValue;
  public int targetFieldLengthFastDataDump; // for fast data dump (StringBuilder size)

  public ConcatFieldsData() {
    super(); // allocate TextFileOutputData
  }
}

==> apache-hop-2.2.0-src.tar.gz: apache-hop-2.2.0/plugins/transforms/concatfields/src/main/java/org/apache/hop/pipeline/transforms/concatfields/ConcatFieldsData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.concatfields;

import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;

import java.util.ArrayList;
import java.util.List;

/*
 * ConcatFieldsData
 *
 */
public class ConcatFieldsData extends BaseTransformData implements ITransformData {
  public List<Integer> inputFieldIndexes;
  public List<Integer> outputFieldIndexes;
  public IRowMeta outputRowMeta;

  public int posTargetField;
  public int[] remainingFieldsInputOutputMapping;
  public String stringSeparator;
  public String stringEnclosure;
  public String[] stringNullValue;
  public int targetFieldLength; // for fast data dump (StringBuilder size)

  public ConcatFieldsData() {
    super(); // allocate TextFileOutputData
  }
}
